==> haskell-hls-change-type-signature-plugin-2.0.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.0.0.0-GCKfFsX5uEzEavlraJatqB

key:
    hls-change-type-signature-plugin-2.0.0.0-GCKfFsX5uEzEavlraJatqB

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  538aca1afdc3d67dafb8732f7818a826
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.0.0.0-GCKfFsX5uEzEavlraJatqB

depends:
    base-4.17.2.1 ghcide-2.0.0.0-AWKPNAHSA153zaZtgTpP3V
    hls-plugin-api-2.0.0.0-8UXQK9xyJ6Qq1nXPMTcOV
    lsp-types-1.6.0.1-KcckgHP1cSAQeTZDkGSeD
    regex-tdfa-1.3.2.2-9m5fW19lHnMJYjjJRSkncP
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-change-type-signature-plugin-2.0.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.0.0.0-6VgdqOAWf7WLUUpoBHnCUZ

key:
    hls-change-type-signature-plugin-2.0.0.0-6VgdqOAWf7WLUUpoBHnCUZ

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  f77da53c62b09b00e2ea48579cfe7b14
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.0.0.0-6VgdqOAWf7WLUUpoBHnCUZ

depends:
    base-4.17.2.1 ghcide-2.0.0.0-DRI4NY9c6PIkGk9WaJTQj
    hls-plugin-api-2.0.0.0-I7YEHyKncWN58S7zoavJND
    lsp-types-1.6.0.1-KcckgHP1cSAQeTZDkGSeD
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
